==> scalapb-runtime_2.12-0.7.1-sources.jar: com/trueaccord/scalapb/package.scala <==
package com.trueaccord

package object scalapb {
  @deprecated("Please use scalapb package instead of com.trueaccord.scalapb", "0.7.0")
  type GeneratedEnum = _root_.scalapb.GeneratedEnum

  @deprecated("Please use scalapb package instead of com.trueaccord.scalapb", "0.7.0")
  type UnrecognizedEnum = _root_.scalapb.UnrecognizedEnum

  @deprecated("Please use scalapb package instead of com.trueaccord.scalapb", "0.7.0")
  type GeneratedEnumCompanion[A <: GeneratedEnum] = _root_.scalapb.GeneratedEnumCompanion[A]

  @deprecated("Please use scalapb package instead of com.trueaccord.scalapb", "0.7.0")
  type GeneratedOneof = _root_.scalapb.GeneratedOneof

  @deprecated("Please use scalapb package instead of com.trueaccord.scalapb", "0.7.0")
  type GeneratedOneofCompanion = _root_.scalapb.GeneratedOneofCompanion

  @deprecated("Please use scalapb package instead of com.trueaccord.scalapb", "0.7.0")
  type GeneratedMessage = _root_.scalapb.GeneratedMessage

  @deprecated("Please use scalapb package instead of com.trueaccord.scalapb", "0.7.0")
  type Message[A] = _root_.scalapb.Message[A]

  @deprecated("Please use scalapb package instead of com.trueaccord.scalapb", "0.7.0")
  type ExtendableMessage[A <: _root_.scalapb.ExtendableMessage[A]] = _root_.scalapb.ExtendableMessage[A]

  @deprecated("Please use scalapb package instead of com.trueaccord.scalapb", "0.7.0")
  val ExtendableMessage = _root_.scalapb.ExtendableMessage

  @deprecated("Please use scalapb package instead of com.trueaccord.scalapb", "0.7.0")
  type JavaProtoSupport[ScalaPB, JavaPB] = _root_.scalapb.JavaProtoSupport[ScalaPB, JavaPB]

  @deprecated("Please use scalapb package instead of com.trueaccord.scalapb", "0.7.0")
  type GeneratedMessageCompanion[A <: GeneratedMessage with Message[A]] = _root_.scalapb.GeneratedMessageCompanion[A]

  @deprecated("Please use scalapb package instead of com.trueaccord.scalapb", "0.7.0")
  type KeyValue[K, V] = _root_.scalapb.KeyValue[K, V]

  @deprecated("Please use scalapb package instead of com.trueaccord.scalapb", "0.7.0")
  type GeneratedFileObject = _root_.scalapb.GeneratedFileObject

  @deprecated("Please use scalapb package instead of com.trueaccord.scalapb", "0.7.0")
  type AnyMethods = _root_.scalapb.AnyMethods

  @deprecated("Please use scalapb package instead of com.trueaccord.scalapb", "0.7.0")
  val AnyMethods = _root_.scalapb.AnyMethods

  @deprecated("Please use scalapb package instead of com.trueaccord.scalapb", "0.7.0")
  type AnyCompanionMethods = _root_.scalapb.AnyCompanionMethods

  @deprecated("Please use scalapb package instead of com.trueaccord.scalapb", "0.7.0")
  val TextFormat = _root_.scalapb.TextFormat

  @deprecated("Please use scalapb package instead of com.trueaccord.scalapb", "0.7.0")
  type TextFormatError = _root_.scalapb.TextFormatError

  @deprecated("Please use scalapb package instead of com.trueaccord.scalapb", "0.7.0")
  type TextFormatException = _root_.scalapb.TextFormatException

  @deprecated("Please use scalapb package instead of com.trueaccord.scalapb", "0.7.0")
  type GeneratedExtension[C <: ExtendableMessage[C], T] = _root_.scalapb.GeneratedExtension[C, T]

  @deprecated("Please use scalapb package instead of com.trueaccord.scalapb", "0.7.0")
  val GeneratedExtension = _root_.scalapb.GeneratedExtension

  @deprecated("Please use scalapb package instead of com.trueaccord.scalapb", "0.7.0")
  val Encoding = _root_.scalapb.Encoding

  @deprecated("Please use scalapb package instead of com.trueaccord.scalapb", "0.7.0")
  val LiteParser = _root_.scalapb.LiteParser

  @deprecated("Please use scalapb package instead of com.trueaccord.scalapb", "0.7.0")
  type TypeMapper[BaseType, CustomType] = _root_.scalapb.TypeMapper[BaseType, CustomType]

  @deprecated("Please use scalapb package instead of com.trueaccord.scalapb", "0.7.0")
  val TypeMapper = _root_.scalapb.TypeMapper

  @deprecated("Please use scalapb package instead of com.trueaccord.scalapb", "0.7.0")
  type UnknownFieldSet = _root_.scalapb.UnknownFieldSet

  @deprecated("Please use scalapb package instead of com.trueaccord.scalapb", "0.7.0")
  val unknownFieldSet = _root_.scalapb.UnknownFieldSet

  @deprecated("Please use scalapb package instead of com.trueaccord.scalapb", "0.7.0")
  val WireType = _root_.scalapb.WireType
}

==> scalapb-runtime_2.12-0.8.0-sources.jar: com/trueaccord/scalapb/package.scala <==
package com.trueaccord

package object scalapb {
  @deprecated("Please use scalapb package instead of com.trueaccord.scalapb", "0.7.0")
  type GeneratedEnum = _root_.scalapb.GeneratedEnum

  @deprecated("Please use scalapb package instead of com.trueaccord.scalapb", "0.7.0")
  type UnrecognizedEnum = _root_.scalapb.UnrecognizedEnum

  @deprecated("Please use scalapb package instead of com.trueaccord.scalapb", "0.7.0")
  type GeneratedEnumCompanion[A <: GeneratedEnum] = _root_.scalapb.GeneratedEnumCompanion[A]

  @deprecated("Please use scalapb package instead of com.trueaccord.scalapb", "0.7.0")
  type GeneratedOneof = _root_.scalapb.GeneratedOneof

  @deprecated("Please use scalapb package instead of com.trueaccord.scalapb", "0.7.0")
  type GeneratedOneofCompanion = _root_.scalapb.GeneratedOneofCompanion

  @deprecated("Please use scalapb package instead of com.trueaccord.scalapb", "0.7.0")
  type GeneratedMessage = _root_.scalapb.GeneratedMessage

  @deprecated("Please use scalapb package instead of com.trueaccord.scalapb", "0.7.0")
  type Message[A] = _root_.scalapb.Message[A]

  @deprecated("Please use scalapb package instead of com.trueaccord.scalapb", "0.7.0")
  type ExtendableMessage[A <: _root_.scalapb.ExtendableMessage[A]] =
    _root_.scalapb.ExtendableMessage[A]

  @deprecated("Please use scalapb package instead of com.trueaccord.scalapb", "0.7.0")
  val ExtendableMessage = _root_.scalapb.ExtendableMessage

  @deprecated("Please use scalapb package instead of com.trueaccord.scalapb", "0.7.0")
  type JavaProtoSupport[ScalaPB, JavaPB] = _root_.scalapb.JavaProtoSupport[ScalaPB, JavaPB]

  @deprecated("Please use scalapb package instead of com.trueaccord.scalapb", "0.7.0")
  type GeneratedMessageCompanion[A <: GeneratedMessage with Message[A]] =
    _root_.scalapb.GeneratedMessageCompanion[A]

  @deprecated("Please use scalapb package instead of com.trueaccord.scalapb", "0.7.0")
  type KeyValue[K, V] = _root_.scalapb.KeyValue[K, V]

  @deprecated("Please use scalapb package instead of com.trueaccord.scalapb", "0.7.0")
  type GeneratedFileObject = _root_.scalapb.GeneratedFileObject

  @deprecated("Please use scalapb package instead of com.trueaccord.scalapb", "0.7.0")
  type AnyMethods = _root_.scalapb.AnyMethods

  @deprecated("Please use scalapb package instead of com.trueaccord.scalapb", "0.7.0")
  val AnyMethods = _root_.scalapb.AnyMethods

  @deprecated("Please use scalapb package instead of com.trueaccord.scalapb", "0.7.0")
  type AnyCompanionMethods = _root_.scalapb.AnyCompanionMethods

  @deprecated("Please use scalapb package instead of com.trueaccord.scalapb", "0.7.0")
  val TextFormat = _root_.scalapb.TextFormat

  @deprecated("Please use scalapb package instead of com.trueaccord.scalapb", "0.7.0")
  type TextFormatError = _root_.scalapb.TextFormatError

  @deprecated("Please use scalapb package instead of com.trueaccord.scalapb", "0.7.0")
  type TextFormatException = _root_.scalapb.TextFormatException

  @deprecated("Please use scalapb package instead of com.trueaccord.scalapb", "0.7.0")
  type GeneratedExtension[C <: ExtendableMessage[C], T] = _root_.scalapb.GeneratedExtension[C, T]

  @deprecated("Please use scalapb package instead of com.trueaccord.scalapb", "0.7.0")
  val GeneratedExtension = _root_.scalapb.GeneratedExtension

  @deprecated("Please use scalapb package instead of com.trueaccord.scalapb", "0.7.0")
  val Encoding = _root_.scalapb.Encoding

  @deprecated("Please use scalapb package instead of com.trueaccord.scalapb", "0.7.0")
  val LiteParser = _root_.scalapb.LiteParser

  @deprecated("Please use scalapb package instead of com.trueaccord.scalapb", "0.7.0")
  type TypeMapper[BaseType, CustomType] = _root_.scalapb.TypeMapper[BaseType, CustomType]

  @deprecated("Please use scalapb package instead of com.trueaccord.scalapb", "0.7.0")
  val TypeMapper = _root_.scalapb.TypeMapper

  @deprecated("Please use scalapb package instead of com.trueaccord.scalapb", "0.7.0")
  type UnknownFieldSet = _root_.scalapb.UnknownFieldSet

  @deprecated("Please use scalapb package instead of com.trueaccord.scalapb", "0.7.0")
  val unknownFieldSet = _root_.scalapb.UnknownFieldSet

  @deprecated("Please use scalapb package instead of com.trueaccord.scalapb", "0.7.0")
  val WireType = _root_.scalapb.WireType
}
